@@ -32,7 +32,7 @@ pref("mail.rights.override", true);
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-#ifdef MOZ_WIDGET_GTK2
+#ifdef MOZ_WIDGET_GTK
 pref("nglayout.enable_drag_images", false);
 #endif
 
@@ -77,17 +77,18 @@ pref("app.update.cert.maxErrors", 5);
 // If these conditions aren't met it will be treated the same as when there is
 // no update available. This validation will not be performed when using the
 // |app.update.url.override| preference for update checking.
-pref("app.update.certs.1.issuerName", "OU=Equifax Secure Certificate Authority,O=Equifax,C=US");
-pref("app.update.certs.1.commonName", "aus3.mozilla.org");
 
-pref("app.update.certs.2.issuerName", "CN=Thawte SSL CA,O=\"Thawte, Inc.\",C=US");
-pref("app.update.certs.2.commonName", "aus3.mozilla.org");
+pref("app.update.certs.1.issuerName", "CN=DigiCert SHA2 Secure Server CA,O=DigiCert Inc,C=US");
+pref("app.update.certs.1.commonName", "aus5.mozilla.org");
+
+pref("app.update.certs.2.issuerName", "CN=thawte SSL CA - G2,O=\"thawte, Inc.\",C=US");
+pref("app.update.certs.2.commonName", "aus5.mozilla.org");
 
 // Whether or not app updates are enabled
-pref("app.update.enabled", true);               
+pref("app.update.enabled", true);
 
 // This preference turns on app.update.mode and allows automatic download and
-// install to take place. We use a separate boolean toggle for this to make     
+// install to take place. We use a separate boolean toggle for this to make
 // the UI easier to construct.
 pref("app.update.auto", true);
 
@@ -101,6 +102,7 @@ pref("app.update.auto", true);
 // See chart in nsUpdateService.js.in for more details
 //
 pref("app.update.mode", 1);
+
 // If set to true, the Update Service will present no UI for any event.
 pref("app.update.silent", false);
 
@@ -109,13 +111,13 @@ pref("app.update.silent", false);
 pref("app.update.staging.enabled", true);
 
 // Update service URL:
-pref("app.update.url", "https://aus3.mozilla.org/update/3/%PRODUCT%/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/update.xml");
+pref("app.update.url", "https://aus5.mozilla.org/update/3/%PRODUCT%/%VERSION%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/update.xml");
 
 // URL user can browse to manually if for some reason all update installation
 // attempts fail.
 pref("app.update.url.manual", "http://www.getthunderbird.com");
 // A default value for the "More information about this update" link
-// supplied in the "An update is available" page of the update wizard. 
+// supplied in the "An update is available" page of the update wizard.
 pref("app.update.url.details", "http://www.mozilla.org/%LOCALE%/%APP%/releases/");
 // User-settable override to app.update.url for testing purposes.
 //pref("app.update.url.override", "");
@@ -126,7 +128,7 @@ pref("app.update.url.details", "http://www.mozilla.org/%LOCALE%/%APP%/releases/"
 pref("app.update.idletime", 60);
 
 // Whether or not we show a dialog box informing the user that the update was
-// successfully applied. This is off in Firefox by default since we show a 
+// successfully applied. This is off in Firefox by default since we show a
 // upgrade start page instead! Other apps may wish to show this UI, and supply
 // a whatsNewURL field in their brand.properties that contains a link to a page
 // which tells users what's new in this new update.
@@ -140,9 +142,16 @@ pref("app.update.service.enabled", true);
 // Release notes URL
 pref("app.releaseNotesURL", "http://live.mozillamessaging.com/%APP%/releasenotes?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");
 
+// URL for "Learn More" for Crash Reporter.
+pref("toolkit.crashreporter.infoURL",
+     "http://www.mozilla.org/thunderbird/legal/privacy/#crash-reporter");");
+
 // Base URL for web-based support pages.
 pref("app.support.baseURL", "http://support.live.mozillamessaging.com/%LOCALE%/%APP%/%APPBUILDID%/");
 
+// Show error messages in error console.
+pref("javascript.options.showInConsole", true);
+
 // Controls enabling of the extension system logging (can reduce performance)
 pref("extensions.logging.enabled", false);
 
@@ -155,6 +164,11 @@ pref("extensions.minCompatibleAppVersion", "5.0");
 
 pref("extensions.update.autoUpdateDefault", true);
 
+pref("extensions.hotfix.id", "thunderbird-hotfix@mozilla.org");
+pref("extensions.hotfix.cert.checkAttributes", true);
+pref("extensions.hotfix.certs.1.sha1Fingerprint", "91:53:98:0C:C1:86:DF:47:8F:35:22:9E:11:C9:A7:31:04:49:A1:AA");
+pref("extensions.hotfix.certs.2.sha1Fingerprint", "39:E7:2B:7A:5B:CF:37:78:F9:5D:4A:E0:53:2D:2F:3D:68:53:C5:60");
+
 // Disable add-ons installed into the shared user and shared system areas by
 // default. This does not include the application directory. See the SCOPE
 // constants in AddonManager.jsm for values to use here
@@ -165,6 +179,8 @@ pref("extensions.getAddons.cache.enabled", true);
 pref("extensions.getAddons.maxResults", 15);
 pref("extensions.getAddons.get.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/guid:%IDS%?src=thunderbird&appOS=%OS%&appVersion=%VERSION%");
 pref("extensions.getAddons.getWithPerformance.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/guid:%IDS%?src=thunderbird&appOS=%OS%&appVersion=%VERSION%&tMain=%TIME_MAIN%&tFirstPaint=%TIME_FIRST_PAINT%&tSessionRestored=%TIME_SESSION_RESTORED%");
+pref("extensions.getAddons.link.url", "https://addons.mozilla.org/%LOCALE%/%APP%/");
+pref("extensions.getAddons.recommended.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/list/recommended/all/%MAX_RESULTS%/%OS%/%VERSION%?src=thunderbird");
 pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/search?q=%TERMS%");
 pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/%MAX_RESULTS%/%OS%/%VERSION%/%COMPATIBILITY_MODE%?src=thunderbird");
 pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%LOCALE%/%APP%/discovery/pane/%VERSION%/%OS%");
@@ -172,12 +188,12 @@ pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
-pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PING_COUNT%/%TOTAL_PING_COUNT%/%DAYS_SINCE_LAST_PING%/");
+pref("extensions.blocklist.url", "https://blocklist.addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PING_COUNT%/%TOTAL_PING_COUNT%/%DAYS_SINCE_LAST_PING%/");
 pref("extensions.blocklist.detailsURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/");
-pref("extensions.blocklist.itemURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/%blockID%");
+pref("extensions.blocklist.itemURL", "https://blocklist.addons.mozilla.org/%LOCALE%/%APP%/blocked/%blockID%");
 
-// Enables some extra Extension System Logging (can reduce performance) 
-pref("extensions.logging.enabled", false); 
+// Enables some extra Extension System Logging (can reduce performance)
+pref("extensions.logging.enabled", false);
 
 // Symmetric (can be overridden by individual extensions) update preferences.
 // e.g.
@@ -189,11 +205,12 @@ pref("extensions.logging.enabled", false);
 pref("extensions.update.enabled", true);
 pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%&compatMode=%COMPATIBILITY_MODE%");
 
-pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
+pref("extensions.update.background.url", "https://versioncheck-bg.addons.mozilla.org/update/VersionCheck.php?reqVersion=%REQ_VERSION%&id=%ITEM_ID%&version=%ITEM_VERSION%&maxAppVersion=%ITEM_MAXAPPVERSION%&status=%ITEM_STATUS%&appID=%APP_ID%&appVersion=%APP_VERSION%&appOS=%APP_OS%&appABI=%APP_ABI%&locale=%APP_LOCALE%&currentAppVersion=%CURRENT_APP_VERSION%&updateType=%UPDATE_TYPE%&compatMode=%COMPATIBILITY_MODE%");
+
+pref("extensions.update.interval", 86400);  // Check for updates to Extensions and
                                             // Themes every day
 
-pref("extensions.getMoreThemesURL", "https://addons.mozilla.org/%LOCALE%/%APP%/themes/");
-pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
+pref("extensions.dss.enabled", false);          // Dynamic Skin Switching
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
 
 pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.name", "chrome://messenger/locale/messenger.properties");
@@ -202,7 +219,6 @@ pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.description", "chrome://
 pref("lightweightThemes.update.enabled", true);
 
 pref("xpinstall.whitelist.add", "addons.mozilla.org");
-pref("xpinstall.whitelist.add.36", "getpersonas.com");
 
 pref("general.smoothScroll", true);
 #ifdef UNIX_BUT_NOT_MAC
@@ -214,18 +230,24 @@ pref("general.autoScroll", true);
 pref("mail.shell.checkDefaultClient", true);
 pref("mail.spellcheck.inline", true);
 
-pref("mail.biff.alert.show_preview", true);
-pref("mail.biff.alert.show_subject", true);
-pref("mail.biff.alert.show_sender",  true);
-pref("mail.biff.alert.preview_length", 40);
-
 pref("mail.folder.views.version", 0);
 
+pref("mail.folderpane.showColumns", false);
+// Force the unit shown for the size of all folders. If empty, the unit
+// is determined automatically for each folder. Allowed values: KB/MB/<empty string>
+pref("mail.folderpane.sizeUnits", "");
+// Summarize messages count and size of subfolders into a collapsed parent?
+// Allowed values: true/false
+pref("mail.folderpane.sumSubfolders", true);
+
 // target folder URI used for the last move or copy
 pref("mail.last_msg_movecopy_target_uri", "");
 // last move or copy operation was a move
 pref("mail.last_msg_movecopy_was_move", true);
 
+//Set the font color for links to something lighter
+pref("browser.anchor_color", "#0B6CDA");
+
 #ifdef XP_WIN
 pref("browser.preferences.instantApply", false);
 #else
@@ -237,6 +259,9 @@ pref("browser.preferences.animateFadeIn", true);
 pref("browser.preferences.animateFadeIn", false);
 #endif
 
+// load the Preferences in a tab
+pref("mail.preferences.inContent", false);
+
 pref("browser.download.show_plugins_in_list", false);
 pref("browser.download.hide_plugins_without_extensions", true);
 
@@ -252,20 +277,22 @@ pref("mail.close_message_window.on_delete", false);
 pref("mailnews.headers.show_n_lines_before_more", 1);
 
 // We want to keep track of what items are appropriate in
-// localstore.rdf.  We use versioning to scrub out the things
+// XULStore.json. We use versioning to scrub out the things
 // that have become obsolete.
 pref("mail.ui-rdf.version", 0);
 
 /////////////////////////////////////////////////////////////////
-// Overrides of the core mailnews.js prefs
+// Overrides of the core mailnews.js and composer.js prefs
 /////////////////////////////////////////////////////////////////
 pref("mail.showCondensedAddresses", true); // show the friendly display name for people I know
 
+pref("mailnews.attachments.display.start_expanded", false);
 // hidden pref for changing how we present attachments in the message pane
 pref("mailnews.attachments.display.view", 0);
 pref("mail.pane_config.dynamic",            0);
 pref("mailnews.reuse_thread_window2",     true);
 pref("editor.singleLine.pasteNewlines", 4);  // substitute commas for new lines in single line text boxes
+pref("editor.CR_creates_new_p", true);
 
 // hidden pref to ensure a certain number of headers in the message pane
 // to avoid the height of the header area from changing when headers are present / not present
@@ -277,6 +304,16 @@ pref("mailnews.reply_header_type", 2);
 
 pref("mail.operate_on_msgs_in_collapsed_threads", true);
 pref("mail.warn_on_collapsed_thread_operation", true);
+pref("mail.warn_on_shift_delete", true);
+
+// When using commands like "next message" or "previous message", leave
+// at least this percentage of the thread pane visible above / below the
+// selected message.
+pref("mail.threadpane.padding.top_percent", 10);
+pref("mail.threadpane.padding.bottom_percent", 10);
+
+// Use correspondents column instead of from/recipient columns.
+pref("mail.threadpane.use_correspondents", false);  // Don't scare TB45 users.
 
 // only affects cookies from RSS articles
 // 0-Accept, 1-dontAcceptForeign, 2-dontUse
@@ -294,7 +331,7 @@ pref("mail.default_html_action", 3);
 
 /////////////////////////////////////////////////////////////////
 // End core mailnews.js pref overrides
-///////////////////////////////////////////////////////////////// 
+/////////////////////////////////////////////////////////////////
 
 /////////////////////////////////////////////////////////////////
 // Overrides for generic app behavior from the core all.js
@@ -316,9 +353,9 @@ pref("offline.download.download_messages",  0);
 #ifdef UNIX_BUT_NOT_MAC
 pref("offline.autoDetect", false);
 #else
-// Windows and Mac can automatically move the user offline or online based on 
+// Windows and Mac can automatically move the user offline or online based on
 // the network connection.
-pref("offline.autoDetect", true); 
+pref("offline.autoDetect", true);
 #endif
 
 // Expose only select protocol handlers. All others should go
@@ -364,10 +401,10 @@ pref("toolkit.telemetry.infoURL", "http://www.mozilla.org/thunderbird/legal/priv
 pref("mousewheel.withcontrolkey.action", 3);
 /////////////////////////////////////////////////////////////////
 // End core all.js pref overrides
-///////////////////////////////////////////////////////////////// 
+/////////////////////////////////////////////////////////////////
 
 /////////////////////////////////////////////////////////////////
-// Generic browser related prefs. 
+// Generic browser related prefs.
 /////////////////////////////////////////////////////////////////
 pref("browser.send_pings", false);
 pref("browser.chrome.toolbar_tips",         true);
@@ -381,63 +418,40 @@ pref("browser.download.folderList", 0);
 pref("browser.download.manager.showAlertOnComplete", false);
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 1);
-pref("browser.download.manager.showWhenStarting", true);
+pref("browser.download.manager.showWhenStarting", false);
 pref("browser.download.manager.closeWhenDone", true);
-pref("browser.download.manager.openDelay", 100);
 pref("browser.download.manager.focusWhenStarting", false);
 pref("browser.download.manager.flashCount", 0);
 pref("browser.download.manager.addToRecentDocs", true);
-
-pref("javascript.options.showInConsole",    true);
+#ifndef XP_MACOSX
+pref("browser.helperApps.deleteTempFileOnExit", true);
+#endif
 
 pref("spellchecker.dictionary", "");
 // Dictionary download preference
 pref("spellchecker.dictionaries.download.url", "https://addons.mozilla.org/%LOCALE%/%APP%/dictionaries/");
 
 // profile.force.migration can be used to bypass the migration wizard, forcing migration from a particular
-// mail application without any user intervention. Possible values are: 
+// mail application without any user intervention. Possible values are:
 // seamonkey (mozilla suite), eudora, oexpress, outlook.
 pref("profile.force.migration", "");
 
 // prefs to control the mail alert notification
 pref("alerts.slideIncrementTime", 50);
-pref("alerts.totalOpenTime", 3000);
+pref("alerts.totalOpenTime", 10000);
 
 // analyze urls in mail messages for scams
 pref("mail.phishing.detection.enabled", true);
 // If phishing detection is enabled, allow fine grained control
 // of the local, static tests
-pref("mail.phishing.detection.ipaddresses", true); 
+pref("mail.phishing.detection.ipaddresses", true);
 pref("mail.phishing.detection.mismatched_hosts", true);
 
-pref("browser.safebrowsing.enabled", false);
-
-// Non-enhanced mode (local url lists) URL list to check for updates
-pref("browser.safebrowsing.provider.0.updateURL", "");
-pref("browser.safebrowsing.dataProvider", 0);
-
-// Does the provider name need to be localizable?
-pref("browser.safebrowsing.provider.0.name", "");
-pref("browser.safebrowsing.provider.0.lookupURL", "");
-pref("browser.safebrowsing.provider.0.keyURL", "");
-pref("browser.safebrowsing.provider.0.reportURL", "");
-
-// HTML report pages
-pref("browser.safebrowsing.provider.0.reportGenericURL", "http://{moz:locale}.phish-generic.mozilla.com/?hl={moz:locale}");
-pref("browser.safebrowsing.provider.0.reportErrorURL", "http://{moz:locale}.phish-error.mozilla.com/?hl={moz:locale}");
-pref("browser.safebrowsing.provider.0.reportPhishURL", "http://{moz:locale}.phish-report.mozilla.com/?hl={moz:locale}");
-
-// FAQ URL
-// XXX Firefox is hard-coded because we haven't got our own version yet.
-pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+pref("browser.safebrowsing.reportPhishURL", "http://%LOCALE%.phish-report.mozilla.com/?hl=%LOCALE%");
 
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
 
-// For the Empty Junk/Trash confirmation dialogs.
-pref("mail.emptyJunk.dontAskAgain", false);
-pref("mail.emptyTrash.dontAskAgain", false);
-
 // If a message is opened using Enter or a double click, what should we do?
 // 0 - open it in a new window
 // 1 - open it in an existing window
@@ -462,6 +476,13 @@ pref("mail.tabs.closeWindowWithLastTab", true);
 // 3 - at the end of the tabstrip
 pref("mail.tabs.closeButtons", 1);
 
+// Allow the tabs to be in the titlebar on supported systems
+#ifdef UNIX_BUT_NOT_MAC
+pref("mail.tabs.drawInTitlebar", false);
+#else
+pref("mail.tabs.drawInTitlebar", true);
+#endif
+
 // The breakpad report server to link to in about:crashes
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
@@ -498,6 +519,9 @@ pref("toolbar.customization.usesheet", true);
 pref("toolbar.customization.usesheet", false);
 #endif
 
+// Number of recipient rows shown by default
+pref("mail.compose.addresswidget.numRowsShownDefault", 3);
+
 // Check for missing attachments?
 pref("mail.compose.attachment_reminder", true);
 // Words that should trigger a missing attachments warning.
@@ -536,6 +560,8 @@ pref("gloda.facetview.hidetimeline", true);
 pref("mailnews.database.global.indexer.enabled", true);
 // Show gloda errors in the error console
 pref("mailnews.database.global.logging.console", true);
+// Limit the number of gloda message results
+pref("mailnews.database.global.search.msg.limit", 1000);
 
 // page to load to find good header add-ons
 pref("mailnews.migration.header_addons_url","http://live.mozillamessaging.com/%APP%/addons/search?q=header&locale=%LOCALE%&lver=%VERSION%&hver=%VERSION%&os=%OS%");
@@ -547,11 +573,8 @@ pref("mailnews.migration.header_addons_url","http://live.mozillamessaging.com/%A
 pref("font.default", "sans-serif");
 pref("font.default.x-unicode", "sans-serif");
 pref("font.default.x-western", "sans-serif");
-pref("font.default.x-central-euro", "sans-serif");
 pref("font.default.x-cyrillic", "sans-serif");
-pref("font.default.x-baltic", "sans-serif");
 pref("font.default.el", "sans-serif");
-pref("font.default.tr", "sans-serif");
 
 #ifdef XP_MACOSX
 pref("font.name.sans-serif.x-unicode", "Lucida Grande");
@@ -568,13 +591,6 @@ pref("font.name-list.monospace.x-western", "Menlo, Monaco");
 pref("font.size.variable.x-western", 15);
 pref("font.size.fixed.x-western", 12);
 
-pref("font.name.sans-serif.x-central-euro", "Lucida Grande");
-pref("font.name.monospace.x-central-euro", "Menlo");
-pref("font.name-list.sans-serif.x-central-euro", "Lucida Grande");
-pref("font.name-list.monospace.x-central-euro", "Menlo, Monaco");
-pref("font.size.variable.x-central-euro", 15);
-pref("font.size.fixed.x-central-euro", 12);
-
 pref("font.name.sans-serif.x-cyrillic", "Lucida Grande");
 pref("font.name.monospace.x-cyrillic", "Menlo");
 pref("font.name-list.sans-serif.x-cyrillic", "Lucida Grande");
@@ -582,26 +598,12 @@ pref("font.name-list.monospace.x-cyrillic", "Menlo, Monaco");
 pref("font.size.variable.x-cyrillic", 15);
 pref("font.size.fixed.x-cyrillic", 12);
 
-pref("font.name.sans-serif.x-baltic", "Lucida Grande");
-pref("font.name.monospace.x-baltic", "Menlo");
-pref("font.name-list.sans-serif.x-baltic", "Lucida Grande");
-pref("font.name-list.monospace.x-baltic", "Menlo, Monaco");
-pref("font.size.variable.x-baltic", 15);
-pref("font.size.fixed.x-baltic", 12);
-
 pref("font.name.sans-serif.el", "Lucida Grande");
 pref("font.name.monospace.el", "Menlo");
 pref("font.name-list.sans-serif.el", "Lucida Grande");
 pref("font.name-list.monospace.el", "Menlo, Monaco");
 pref("font.size.variable.el", 15);
 pref("font.size.fixed.el", 12);
-
-pref("font.name.sans-serif.tr", "Lucida Grande");
-pref("font.name.monospace.tr", "Menlo");
-pref("font.name-list.sans-serif.tr", "Lucida Grande");
-pref("font.name-list.monospace.tr", "Menlo, Monaco");
-pref("font.size.variable.tr", 15);
-pref("font.size.fixed.tr", 12);
 #endif
 
 // Since different versions of Windows need different settings, we'll handle
@@ -620,25 +622,13 @@ pref("font.name-list.serif.x-western", "serif");
 pref("font.name-list.sans-serif.x-western", "sans-serif");
 pref("font.name-list.monospace.x-western", "monospace");
 
-pref("font.name-list.serif.x-central-euro", "serif");
-pref("font.name-list.sans-serif.x-central-euro", "sans-serif");
-pref("font.name-list.monospace.x-central-euro", "monospace");
-
 pref("font.name-list.serif.x-cyrillic", "serif");
 pref("font.name-list.sans-serif.x-cyrillic", "sans-serif");
 pref("font.name-list.monospace.x-cyrillic", "monospace");
 
-pref("font.name-list.serif.x-baltic", "serif");
-pref("font.name-list.sans-serif.x-baltic", "sans-serif");
-pref("font.name-list.monospace.x-baltic", "monospace");
-
 pref("font.name-list.serif.el", "serif");
 pref("font.name-list.sans-serif.el", "sans-serif");
 pref("font.name-list.monospace.el", "monospace");
-
-pref("font.name-list.serif.tr", "serif");
-pref("font.name-list.sans-serif.tr", "sans-serif");
-pref("font.name-list.monospace.tr", "monospace");
 #endif
 
 pref("mail.font.windows.version", 0);
@@ -672,10 +662,15 @@ pref("browser.tabs.loadDivertedInBackground", false);
 pref("browser.chrome.site_icons", true);
 pref("browser.chrome.favicons", true);
 
-// Disable places by default as we don't want to store global history
+// Enable places by default as we want to store global history for visited links
 // Below we define reasonable defaults as copied from Firefox so that we have
-// something sensible should an extension wish to enable this.
-pref("places.history.enabled", false);
+// something sensible.
+pref("places.history.enabled", true);
+
+// With places disabled by default, the default growth increment is set to zero
+// as it would otherwise default to 10MB as the minimum space occupied by the
+// places.sqlite database in the profile.
+pref("places.database.growthIncrementKiB", 0);
 
 // The percentage of system memory that the Places database can use.  Out of the
 // allowed cache size it will at most use the size of the database file.
@@ -750,9 +745,8 @@ pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
 php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=
 %CLIENT_OS%&chromeLocale=%CHROME_LOCALE%&appRelease=%APP_RELEASE%");
 
-// By default we show an infobar message when pages require plugins the user has
-// not installed, or are outdated.
-pref("plugins.hide_infobar_for_missing_plugin", false);
+// By default we show an infobar message when pages require plugins that are
+// outdated.
 pref("plugins.hide_infobar_for_outdated_plugin", false);
 
 #ifdef XP_MACOSX
@@ -760,10 +754,24 @@ pref("plugins.use_layers", false);
 pref("plugins.hide_infobar_for_carbon_failure_plugin", false);
 #endif
 
-pref("plugins.update.url", "https://www.mozilla.com/%LOCALE%/plugincheck/");
+pref("plugins.update.url", "https://www.mozilla.org/%LOCALE%/plugincheck/");
 pref("plugins.update.notifyUser", false);
 pref("plugins.crash.supportUrl", "https://live.mozillamessaging.com/%APP%/plugin-crashed?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");
 
+// Click-to-play has not been ported for TB yet, see bug 814168.
+// The default plugin state should be changed to "ask to activate" when this
+// has been done.
+pref("plugins.click_to_play", false);
+// Disable by default.
+pref("plugin.default.state", 0);
+
+// Plugins bundled in XPIs are enabled by default.
+pref("plugin.defaultXpi.state", 2);
+
+// Flash is enabled and Java is disabled by default.
+pref("plugin.state.flash", 2);
+pref("plugin.state.java", 0);
+
 // Windows taskbar support
 #ifdef XP_WIN
 pref("mail.taskbar.lists.enabled", true);
@@ -773,17 +781,15 @@ pref("mail.taskbar.lists.tasks.enabled", true);
 // Disable hardware accelerated layers
 pref("layers.acceleration.disabled", true);
 #ifdef XP_WIN
-// and direct2d support on Windows
+// and direct2d support on Windows.
 pref("gfx.direct2d.disabled", true);
 #endif
-
+ 
 // Account provisioner.
 pref("mail.provider.providerList", "https://broker-live.mozillamessaging.com/provider/list");
 pref("mail.provider.suggestFromName", "https://broker-live.mozillamessaging.com/provider/suggest");
 pref("mail.provider.enabled", true);
 
-pref("mail.websearch.open_externally", false);
-
 // Pointer to the default engine name.
 pref("browser.search.defaultenginename", "chrome://messenger-region/locale/region.properties");
 
@@ -792,6 +798,11 @@ pref("browser.search.order.1", "chrome://messenger-region/locale/region.properti
 pref("browser.search.order.2", "chrome://messenger-region/locale/region.properties");
 pref("browser.search.order.3", "chrome://messenger-region/locale/region.properties");
 
+pref("browser.search.defaultenginename.US", "data:text/plain,browser.search.defaultenginename.US=Bing");
+pref("browser.search.order.US.1", "data:text/plain,browser.search.defaultenginename.US=Bing");
+pref("browser.search.order.US.2", "data:text/plain,browser.search.defaultenginename.US=Yahoo");
+pref("browser.search.order.US.3", "data:text/plain,browser.search.defaultenginename.US=");
+
 // XXX Don't update yet, until we've verified how that affects us.
 pref("browser.search.update", false);
 
@@ -802,14 +813,54 @@ pref("browser.search.update.interval", 21600);
 pref("devtools.debugger.log", false);
 
 pref("mail.chat.enabled", true);
-pref("mail.chat.play_notification_sound", true);
-// Send typing notification in private conversations
-pref("purple.conversations.im.send_typing", true);
+// Whether to show chat notifications or not.
+pref("mail.chat.show_desktop_notifications", true);
+// Decide how much information is to be shown in the notification.
+// 0 == Show all info (sender, chat message message preview),
+// 1 == Show sender's info only (not message preview),
+// 2 == No info (fill dummy values).
+pref("mail.chat.notification_info", 0);
+pref("mail.chat.play_sound", true);
+// 0 == default system sound, 1 == user specified wav
+pref("mail.chat.play_sound.type", 0);
+// if sound is user specified, this needs to be a file url
+pref("mail.chat.play_sound.url", "");
 
 // BigFiles
 pref("mail.cloud_files.enabled", true);
 pref("mail.cloud_files.inserted_urls.footer.link", "http://www.getthunderbird.com");
 pref("mail.cloud_files.learn_more_url", "https://support.mozillamessaging.com/kb/filelink-large-attachments");
 
+// Ignore threads
+pref("mail.ignore_thread.learn_more_url", "https://support.mozillamessaging.com/kb/ignore-threads");
+
+// Sanitize dialog window
+pref("privacy.cpd.history", true);
+pref("privacy.cpd.cookies", true);
+pref("privacy.cpd.cache", true);
+
+// What default should we use for the time span in the sanitizer:
+// 0 - Clear everything
+// 1 - Last Hour
+// 2 - Last 2 Hours
+// 3 - Last 4 Hours
+// 4 - Today
+pref("privacy.sanitize.timeSpan", 1);
+
 // PgpMime Proxy
 pref("mail.pgpmime.addon_url", "https://addons.mozilla.org/thunderbird/addon/enigmail/");
+
+// If set to true, Thunderbird will collapse the main menu for new profiles
+// (or, more precisely, profiles that start with no accounts created).
+pref("mail.main_menu.collapse_by_default", true);
+
+// If set to true, when saving a message to a file, use underscore
+// instead of space in the file name.
+pref("mail.save_msg_filename_underscores_for_space", false);
+
+// Disable cache v2 since migration has not been done, it is pending in bug 1021843.
+pref("browser.cache.use_new_backend",       0);
+pref("browser.cache.use_new_backend_temp",  false);
+
+// calendar promotion status
+pref("mail.calendar-integration.opt-out", false);
