@@ -15,20 +15,22 @@
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
-XPCOMUtils.defineLazyGetter(this, "PageMenu", function() {
+var gContextMenuContentData = null;
+
+XPCOMUtils.defineLazyGetter(this, "PageMenuParent", function() {
   let tmp = {};
   Components.utils.import("resource://gre/modules/PageMenu.jsm", tmp);
-  return new tmp.PageMenu();
+  return new tmp.PageMenuParent();
 });
 
-function nsContextMenu(aXulMenu, aBrowser, aIsShift) {
+function nsContextMenu(aXulMenu, aIsShift, aEvent) {
   this.shouldDisplay = true;
-  this.initMenu(aBrowser, aXulMenu, aIsShift);
+  this.initMenu(aXulMenu, aIsShift, aEvent);
 }
 
 // Prototype for nsContextMenu "class."
 nsContextMenu.prototype = {
-  initMenu: function(aBrowser, aXulMenu, aIsShift) {
+  initMenu: function(aXulMenu, aIsShift, aEvent) {
     // Get contextual info.
     this.setTarget(document.popupNode, document.popupRangeParent,
                    document.popupRangeOffset);
@@ -39,8 +41,7 @@ nsContextMenu.prototype = {
     this.hasPageMenu = false;
     if (!aIsShift && this.browser.docShell.allowJavascript &&
         Services.prefs.getBoolPref("javascript.enabled"))
-      this.hasPageMenu = PageMenu.maybeBuildAndAttachMenu(this.target,
-                                                          aXulMenu);
+      this.hasPageMenu = PageMenuParent.buildAndAddToPopup(this.target, aXulMenu);
 
     this.isTextSelected = this.isTextSelection();
     this.isContentSelected = this.isContentSelection();
@@ -49,9 +50,66 @@ nsContextMenu.prototype = {
 
     // Initialize (disable/remove) menu items.
     this.initItems();
+    // Initialize gContextMenuContentData.
+    if (aEvent)
+      this.initContentData(aEvent);
+  },
+
+  initContentData: function(aEvent) {
+    var addonInfo = {};
+    var subject = {
+      event: aEvent,
+      addonInfo: addonInfo,
+    };
+    subject.wrappedJSObject = subject;
+    // Notifies the Addon-SDK which then populates addonInfo.
+    Services.obs.notifyObservers(subject, "content-contextmenu", null);
+
+    var popupNode = this.target;
+    var doc = popupNode.ownerDocument;
+
+    var contentType = null;
+    var contentDisposition = null;
+    if (this.onImage) {
+      try {
+        let imageCache = Components.classes["@mozilla.org/image/tools;1"]
+                                   .getService(Components.interfaces.imgITools)
+                                   .getImgCacheForDocument(doc);
+        let props = imageCache.findEntryProperties(popupNode.currentURI);
+        if (props) {
+          let nsISupportsCString = Components.interfaces.nsISupportsCString;
+          contentType = props.get("type", nsISupportsCString).data;
+          try {
+            contentDisposition = props.get("content-disposition",
+                                           nsISupportsCString).data;
+          } catch (e) {}
+        }
+      } catch (e) {
+        Components.utils.reportError(e);
+      }
+    }
+
+    gContextMenuContentData = {
+      isRemote: false,
+      event: aEvent,
+      popupNode: popupNode,
+      browser: this.browser,
+      addonInfo: addonInfo,
+      documentURIObject: doc.documentURIObject,
+      docLocation: doc.location.href,
+      charSet: doc.characterSet,
+      referrer: doc.referrer,
+      referrerPolicy: doc.referrerPolicy,
+      contentType: contentType,
+      contentDisposition: contentDisposition,
+      frameOuterWindowID: doc.defaultView.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                                         .getInterface(Components.interfaces.nsIDOMWindowUtils)
+                                         .outerWindowID,
+    };
   },
 
   hiding: function () {
+    gContextMenuContentData = null;
     InlineSpellCheckerUI.clearSuggestionsFromMenu();
     InlineSpellCheckerUI.clearDictionaryListFromMenu();
     InlineSpellCheckerUI.uninit();
@@ -276,7 +334,8 @@ nsContextMenu.prototype = {
   },
 
   initSpellingItems: function() {
-    var canSpell = InlineSpellCheckerUI.canSpellCheck;
+    var canSpell = InlineSpellCheckerUI.canSpellCheck &&
+                   !InlineSpellCheckerUI.initialSpellCheckPending;
     var onMisspelling = InlineSpellCheckerUI.overMisspelling;
     var showUndo = InlineSpellCheckerUI.enabled &&
                    InlineSpellCheckerUI.canUndo();
@@ -377,12 +436,12 @@ nsContextMenu.prototype = {
                   onMedia && !this.target.paused && !this.target.ended);
     this.showItem("context-media-mute", onMedia && !this.target.muted);
     this.showItem("context-media-unmute", onMedia && this.target.muted);
+    this.showItem("context-media-playbackrate", onMedia);
     this.showItem("context-media-showcontrols", onMedia && !this.target.controls);
     this.showItem("context-media-hidecontrols", onMedia && this.target.controls);
     this.showItem("context-video-fullscreen", this.onVideo);
 
-    var statsShowing = this.onVideo &&
-                       this.target.wrappedJSObject.mozMediaStatisticsShowing;
+    var statsShowing = this.onVideo && this.target.mozMediaStatisticsShowing;
     this.showItem("context-video-showstats",
                   this.onVideo && this.target.controls && !statsShowing);
     this.showItem("context-video-hidestats",
@@ -390,12 +449,17 @@ nsContextMenu.prototype = {
 
     // Disable them when there isn't a valid media source loaded.
     if (onMedia) {
+      this.setItemAttr("context-media-playbackrate-050", "checked", this.target.playbackRate == 0.5);
+      this.setItemAttr("context-media-playbackrate-100", "checked", this.target.playbackRate == 1.0);
+      this.setItemAttr("context-media-playbackrate-150", "checked", this.target.playbackRate == 1.5);
+      this.setItemAttr("context-media-playbackrate-200", "checked", this.target.playbackRate == 2.0);
       var hasError = this.target.error != null ||
                      this.target.networkState == this.target.NETWORK_NO_SOURCE;
       this.setItemAttr("context-media-play", "disabled", hasError);
       this.setItemAttr("context-media-pause", "disabled", hasError);
       this.setItemAttr("context-media-mute", "disabled", hasError);
       this.setItemAttr("context-media-unmute", "disabled", hasError);
+      this.setItemAttr("context-media-playbackrate", "disabled", hasError);
       this.setItemAttr("context-media-showcontrols", "disabled", hasError);
       this.setItemAttr("context-media-hidecontrols", "disabled", hasError);
       if (this.onVideo) {
@@ -462,12 +526,13 @@ nsContextMenu.prototype = {
                            .chromeEventHandler;
       var editingSession = webNav.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
                                  .getInterface(Components.interfaces.nsIEditingSession);
-      if (editingSession.windowIsEditable(win) && this.isTargetEditable()) {
+      if (editingSession.windowIsEditable(win) &&
+          this.isTargetEditable() && this.target.spellcheck) {
         this.onTextInput           = true;
         this.possibleSpellChecking = true;
         InlineSpellCheckerUI.init(editingSession.getEditorForWindow(win));
-        var canSpell = InlineSpellCheckerUI.canSpellCheck;
         InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
+        var canSpell = InlineSpellCheckerUI.canSpellCheck;
         this.showItem("spell-check-enabled", canSpell);
         this.showItem("spell-separator", canSpell);
         return;
@@ -516,7 +581,7 @@ nsContextMenu.prototype = {
         this.onTextInput = this.isTargetATextBox(this.target);
         // allow spellchecking UI on all writable text boxes except passwords
         if (this.onTextInput && !this.target.readOnly &&
-            this.target.mozIsTextField(true)) {
+            this.target.mozIsTextField(true) && this.target.spellcheck) {
           this.possibleSpellChecking = true;
           InlineSpellCheckerUI.init(this.target.QueryInterface(Components.interfaces.nsIDOMNSEditableElement).editor);
           InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
@@ -525,7 +590,7 @@ nsContextMenu.prototype = {
       }
       else if (this.target instanceof HTMLTextAreaElement) {
         this.onTextInput = this.isTextBoxEnabled(this.target);
-        if (this.onTextInput && !this.target.readOnly) {
+        if (this.onTextInput && !this.target.readOnly && this.target.spellcheck) {
           this.possibleSpellChecking = true;
           InlineSpellCheckerUI.init(this.target.QueryInterface(Components.interfaces.nsIDOMNSEditableElement).editor);
           InlineSpellCheckerUI.initFromEvent(aRangeParent, aRangeOffset);
@@ -733,29 +798,27 @@ nsContextMenu.prototype = {
   if (aBlock)
     Services.perms.add(uri, "image", Services.perms.DENY_ACTION);
   else
-    Services.perms.remove(uri.host, "image");
+    Services.perms.remove(uri, "image");
   },
 
   // Open linked-to URL in a new tab.
   openLinkInTab: function(aEvent) {
     // Determine linked-to URL.
-    return openNewTabWith(this.linkURL, this.target.ownerDocument, null,
-                          aEvent);
+    return openNewTabWith(this.linkURL, this.link, null, aEvent);
   },
 
   // Open linked-to URL in a new window.
   openLinkInWindow: function() {
-    return openNewWindowWith(this.linkURL, this.target.ownerDocument);
+    return openNewWindowWith(this.linkURL, this.link);
   },
 
   // Open linked-to URL in a private window.
   openLinkInPrivateWindow: function() {
-    return openNewPrivateWith(this.linkURL, this.target.ownerDocument);
+    return openNewPrivateWith(this.linkURL, this.link);
   },
 
   // Open frame in a new tab.
   openFrameInTab: function(aEvent) {
-    // Determine linked-to URL.
     return openNewTabWith(this.target.ownerDocument.location.href,
                           this.target.ownerDocument, null, aEvent);
   },
@@ -771,6 +834,11 @@ nsContextMenu.prototype = {
                              this.target.ownerDocument);
   },
 
+  printFrame: function() {
+    PrintUtils.printWindow(gContextMenuContentData.frameOuterWindowID,
+                           this.browser);
+  },
+
   // Open clicked-in frame in the same window
   showOnlyThisFrame: function() {
     openTopWin( this.target.ownerDocument.location.href, this.target.ownerDocument.defaultView );
@@ -778,34 +846,18 @@ nsContextMenu.prototype = {
 
   // View Partial Source
   viewPartialSource: function(aContext) {
-    var focusedWindow = document.commandDispatcher.focusedWindow;
-    if (focusedWindow == window)
-      focusedWindow = content;
-
-    var docCharset = null;
-    if (focusedWindow)
-      docCharset = "charset=" + focusedWindow.document.characterSet;
-
-    // "View Selection Source" and others such as "View MathML Source"
-    // are mutually exclusive, with the precedence given to the selection
-    // when there is one
-    var reference = null;
-    if (aContext == "selection")
-      reference = focusedWindow.getSelection();
-    else if (aContext == "mathml")
-      reference = this.target;
-    else
-      throw "not reached";
-
-    var docUrl = null; // unused (and play nice for fragments generated via XSLT too)
-    window.openDialog("chrome://global/content/viewPartialSource.xul",
-                      "_blank", "all,dialog=no",
-                      docUrl, docCharset, reference, aContext);
+    var browser = getBrowser().selectedBrowser;
+    var target = aContext == "mathml" ? this.target : null;
+    gViewSourceUtils.viewPartialSourceInBrowser(browser, target, null);
   },
 
   // Open new "view source" window with the frame's URL.
   viewFrameSource: function() {
-    BrowserViewSourceOfDocument(this.target.ownerDocument);
+    gViewSourceUtils.viewSource({
+      browser: this.browser,
+      URL: gContextMenuContentData.docLocation,
+      outerWindowID: gContextMenuContentData.frameOuterWindowID,
+    });
   },
 
   viewInfo: function() {
@@ -994,7 +1046,12 @@ nsContextMenu.prototype = {
     }
 
     // set up a channel to do the saving
-    var channel = Services.io.newChannel(linkURL, null, null);
+    var ios = Services.io;
+    var channel = ios.newChannel2(linkURL, null, null, null,
+                                  Services.scriptSecurityManager.getSystemPrincipal(),
+                                  null,
+                                  Components.interfaces.nsILoadInfo.SEC_NORMAL,
+                                  Components.interfaces.nsIContentPolicy.TYPE_OTHER);
     channel.notificationCallbacks = new Callbacks();
 
     var flags = Components.interfaces.nsIChannel.LOAD_CALL_CONTENT_SNIFFERS;
@@ -1372,7 +1429,7 @@ nsContextMenu.prototype = {
     return false;
   },
 
-  mediaCommand: function(aCommand) {
+  mediaCommand: function(aCommand, aData) {
     var media = this.target;
 
     switch (aCommand) {
@@ -1388,6 +1445,9 @@ nsContextMenu.prototype = {
       case "unmute":
         media.muted = false;
         break;
+      case "playbackRate":
+        media.playbackRate = aData;
+        break;
       case "hidecontrols":
         media.removeAttribute("controls");
         break;
